/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IMergeTreeAnnotateMsg } from "./ops.js";
import { PropertySet } from "./properties.js";
/**
 * @internal
 */
export declare enum PropertiesRollback {
    /**
     * Not in a rollback
     */
    None = 0,
    /**
     * Rollback
     */
    Rollback = 1
}
/**
 * Minimally copies properties and the property manager from source to destination.
 * @internal
 */
export declare function copyPropertiesAndManager(source: {
    properties?: PropertySet;
    propertyManager?: PropertiesManager;
}, destination: {
    properties?: PropertySet;
    propertyManager?: PropertiesManager;
}): void;
/**
 * @internal
 */
export declare class PropertiesManager {
    private pendingKeyUpdateCount;
    ackPendingProperties(annotateOp: IMergeTreeAnnotateMsg): void;
    private decrementPendingCounts;
    addProperties(oldProps: PropertySet, newProps: PropertySet, seq?: number, collaborating?: boolean, rollback?: PropertiesRollback): PropertySet;
    copyTo(oldProps: PropertySet, newProps: PropertySet | undefined, newManager: PropertiesManager): PropertySet | undefined;
    /**
     * Determines if all of the defined properties in a given property set are pending.
     */
    hasPendingProperties(props: PropertySet): boolean;
    hasPendingProperty(key: string): boolean;
}
//# sourceMappingURL=segmentPropertiesManager.d.ts.map